@@ -1,6 +1,6 @@
 package List::Objects::WithUtils::Autobox;
 {
-  $List::Objects::WithUtils::Autobox::VERSION = '2.007001';
+  $List::Objects::WithUtils::Autobox::VERSION = '2.008001';
 }
 use strictures 1;
 require Carp;
@@ -47,7 +47,7 @@ List::Objects::WithUtils::Autobox - Native data types WithUtils
 
   use List::Objects::WithUtils 'autobox';
 
-  my @upper = [ qw/foo bar baz/ ]->map(sub { uc $_[0] })->all;
+  my @upper = [ qw/foo bar baz/ ]->map(sub { uc })->all;
 
   my @sorted_keys = { foo => 'bar', baz => 'quux' }->keys->sort->all;
 
